@@ -3,7 +3,7 @@ use parent 'HealthCheck::Diagnostic';
 
 # ABSTRACT: Make HTTP/HTTPS requests to web servers to check connectivity
 use version;
-our $VERSION = 'v1.3.5'; # VERSION
+our $VERSION = 'v1.4.0'; # VERSION
 
 use strict;
 use warnings;
@@ -20,8 +20,19 @@ sub new {
         ? %{ $params[0] } : @params;
 
     my @bad_params = grep {
-        !/^(tags|label|id|options|timeout|url|request|options|content_regex|status_code_eval|status_code|no_follow_redirects)$/
-    } keys %params; 
+        !/^(  content_regex
+            | id
+            | label
+            | no_follow_redirects
+            | options
+            | request
+            | status_code
+            | status_code_eval
+            | tags
+            | timeout
+            | url
+        )$/x
+    } keys %params;
 
     carp("Invalid parameter: " . join(", ", @bad_params)) if @bad_params;
 
@@ -52,6 +63,7 @@ sub new {
     $params{options}        //= {};
     $params{options}{agent} //= LWP::UserAgent->_agent .
         " HealthCheck-Diagnostic-WebRequest/" . ( $class->VERSION || '0' );
+    $params{options}{timeout} //= 7;    # Decided by committee
 
     return $class->SUPER::new(
         label => 'web_request',
@@ -153,7 +165,7 @@ HealthCheck::Diagnostic::WebRequest - Make HTTP/HTTPS requests to web servers to
 
 =head1 VERSION
 
-version v1.3.5
+version v1.4.0
 
 =head1 SYNOPSIS
 
@@ -290,6 +302,8 @@ pairs in order to configure things like ssl_opts, timeout, etc.
 
 It is optional.
 
+By default provides a custom C<agent> string and a default C<timeout> of 7.
+
 =head1 DEPENDENCIES
 
 L<HealthCheck::Diagnostic>
